From 46f69809601c73ef5316e668e9253e609187e80d Mon Sep 17 00:00:00 2001
From: Elis Axelsson <elis.axelsson@gmail.com>
Date: Sat, 5 Aug 2017 10:56:12 +0200
Subject: [PATCH] Add support for extensions in the PATH

This patch makes pass load extensions from the $PATH by the name
pass-EXTENSION so distributions can put the files wherever they
want. This would make it easier for certain distros to package
extensions (example NixOS that has it's own directory structure).
---
 man/pass.1            | 3 +++
 src/password-store.sh | 8 +++++++-
 2 files changed, 10 insertions(+), 1 deletion(-)

diff --git a/man/pass.1 b/man/pass.1
index e842178..227173b 100644
--- a/man/pass.1
+++ b/man/pass.1
@@ -36,6 +36,9 @@ password store and is executable, then it is sourced into the environment,
 passing any arguments and environment variables. Extensions existing in a
 system-wide directory, only installable by the administrator, are always enabled.
 
+Extensions can also be named pass-EXTENSION_NAME and be executable within
+your PATH.
+
 Otherwise COMMAND must be one of the valid commands listed below.
 
 Several of the commands below rely on or provide additional functionality if
diff --git a/src/password-store.sh b/src/password-store.sh
index d77ff12..f181c8c 100755
--- a/src/password-store.sh
+++ b/src/password-store.sh
@@ -656,14 +656,20 @@ cmd_extension_or_show() {
 SYSTEM_EXTENSION_DIR=""
 cmd_extension() {
 	check_sneaky_paths "$1"
-	local user_extension system_extension extension
+	local user_extension system_extension path_extension extension
+
 	[[ -n $SYSTEM_EXTENSION_DIR ]] && system_extension="$SYSTEM_EXTENSION_DIR/$1.bash"
 	[[ $PASSWORD_STORE_ENABLE_EXTENSIONS == true ]] && user_extension="$EXTENSIONS/$1.bash"
+	[[ -f $(command -v "pass-$1") ]] && path_extension=$(command -v "pass-$1")
+
 	if [[ -n $user_extension && -f $user_extension && -x $user_extension ]]; then
 		verify_file "$user_extension"
 		extension="$user_extension"
 	elif [[ -n $system_extension && -f $system_extension && -x $system_extension ]]; then
 		extension="$system_extension"
+	elif [[ -n $path_extension && -f $path_extension && -x $path_extension ]]; then
+		verify_file "$path_extension"
+		extension="$path_extension"
 	else
 		return 1
 	fi
-- 
2.13.3

